@@ -30,6 +30,7 @@
 
 // standard headers
 #include <chrono>
+#include <cmath>
 
 
 using namespace std::chrono_literals;
@@ -106,25 +107,25 @@ void AlsaPlayer::setHardwareVolume(const Volume& volume)
             LOG(ERROR, LOG_TAG) << "Failed to mute, error: " << snd_strerror(err) << "\n";
 
         long minv, maxv;
-        if ((err = snd_mixer_selem_get_playback_dB_range(elem_, &minv, &maxv)) == 0)
+        if (err = snd_mixer_selem_get_playback_dB_range(elem_, &minv, &maxv); err == 0)
         {
             double min_norm = exp10((minv - maxv) / 6000.0);
             double vol = volume.volume * (1 - min_norm) + min_norm;
             double mixer_volume = 6000.0 * log10(vol) + maxv;
 
             LOG(DEBUG, LOG_TAG) << "Mixer playback dB range [" << minv << ", " << maxv << "], volume: " << vol << ", mixer volume: " << mixer_volume << "\n";
-            if ((err = snd_mixer_selem_set_playback_dB_all(elem_, mixer_volume, 0)) < 0)
+            if (err = snd_mixer_selem_set_playback_dB_all(elem_, mixer_volume, 0); err < 0)
                 throw SnapException(std::string("Failed to set playback volume, error: ") + snd_strerror(err));
         }
         else
         {
-            if ((err = snd_mixer_selem_get_playback_volume_range(elem_, &minv, &maxv)) < 0)
+            if (err = snd_mixer_selem_get_playback_volume_range(elem_, &minv, &maxv); err < 0)
                 throw SnapException(std::string("Failed to get playback volume range, error: ") + snd_strerror(err));
 
             auto mixer_volume = volume.volume * (maxv - minv) + minv;
             LOG(DEBUG, LOG_TAG) << "Mixer playback volume range [" << minv << ", " << maxv << "], volume: " << volume.volume
                                 << ", mixer volume: " << mixer_volume << "\n";
-            if ((err = snd_mixer_selem_set_playback_volume_all(elem_, mixer_volume)) < 0)
+            if (err = snd_mixer_selem_set_playback_volume_all(elem_, mixer_volume); err < 0)
                 throw SnapException(std::string("Failed to set playback volume, error: ") + snd_strerror(err));
         }
     }
@@ -149,9 +150,9 @@ bool AlsaPlayer::getHardwareVolume(Volume& volume)
         while (snd_mixer_handle_events(mixer_) > 0)
             this_thread::sleep_for(1us);
         long minv, maxv;
-        if ((err = snd_mixer_selem_get_playback_dB_range(elem_, &minv, &maxv)) == 0)
+        if (err = snd_mixer_selem_get_playback_dB_range(elem_, &minv, &maxv); err == 0)
         {
-            if ((err = snd_mixer_selem_get_playback_dB(elem_, SND_MIXER_SCHN_MONO, &vol)) < 0)
+            if (err = snd_mixer_selem_get_playback_dB(elem_, SND_MIXER_SCHN_MONO, &vol); err < 0)
                 throw SnapException(std::string("Failed to get playback volume, error: ") + snd_strerror(err));
 
             volume.volume = pow(10, (vol - maxv) / 6000.0);
@@ -163,9 +164,9 @@ bool AlsaPlayer::getHardwareVolume(Volume& volume)
         }
         else
         {
-            if ((err = snd_mixer_selem_get_playback_volume_range(elem_, &minv, &maxv)) < 0)
+            if (err = snd_mixer_selem_get_playback_volume_range(elem_, &minv, &maxv); err < 0)
                 throw SnapException(std::string("Failed to get playback volume range, error: ") + snd_strerror(err));
-            if ((err = snd_mixer_selem_get_playback_volume(elem_, SND_MIXER_SCHN_MONO, &vol)) < 0)
+            if (err = snd_mixer_selem_get_playback_volume(elem_, SND_MIXER_SCHN_MONO, &vol); err < 0)
                 throw SnapException(std::string("Failed to get playback volume, error: ") + snd_strerror(err));
 
             vol -= minv;
@@ -173,7 +174,7 @@ bool AlsaPlayer::getHardwareVolume(Volume& volume)
             volume.volume = static_cast<double>(vol) / static_cast<double>(maxv);
         }
         int val;
-        if ((err = snd_mixer_selem_get_playback_switch(elem_, SND_MIXER_SCHN_MONO, &val)) < 0)
+        if (err = snd_mixer_selem_get_playback_switch(elem_, SND_MIXER_SCHN_MONO, &val); err < 0)
             throw SnapException(std::string("Failed to get mute state, error: ") + snd_strerror(err));
         volume.mute = (val == 0);
         LOG(DEBUG, LOG_TAG) << "Get volume, mixer volume range [" << minv << ", " << maxv << "], volume: " << volume.volume << ", muted: " << volume.mute
@@ -250,9 +251,9 @@ void AlsaPlayer::initMixer()
     LOG(DEBUG, LOG_TAG) << "initMixer\n";
     std::lock_guard<std::recursive_mutex> lock(rec_mutex_);
     int err;
-    if ((err = snd_ctl_open(&ctl_, mixer_device_.c_str(), SND_CTL_READONLY)) < 0)
+    if (err = snd_ctl_open(&ctl_, mixer_device_.c_str(), SND_CTL_READONLY); err < 0)
         throw SnapException("Can't open control for " + mixer_device_ + ", error: " + snd_strerror(err));
-    if ((err = snd_ctl_subscribe_events(ctl_, 1)) < 0)
+    if (err = snd_ctl_subscribe_events(ctl_, 1); err < 0)
         throw SnapException("Can't subscribe for events for " + mixer_device_ + ", error: " + snd_strerror(err));
     fd_ = std::unique_ptr<pollfd, std::function<void(pollfd*)>>(new pollfd(), [](pollfd* p)
     {
@@ -270,13 +271,13 @@ void AlsaPlayer::initMixer()
     snd_mixer_selem_id_set_index(sid, mix_index);
     snd_mixer_selem_id_set_name(sid, mixer_name_.c_str());
 
-    if ((err = snd_mixer_open(&mixer_, 0)) < 0)
+    if (err = snd_mixer_open(&mixer_, 0); err < 0)
         throw SnapException(std::string("Failed to open mixer, error: ") + snd_strerror(err));
-    if ((err = snd_mixer_attach(mixer_, mixer_device_.c_str())) < 0)
+    if (err = snd_mixer_attach(mixer_, mixer_device_.c_str()); err < 0)
         throw SnapException("Failed to attach mixer to " + mixer_device_ + ", error: " + snd_strerror(err));
-    if ((err = snd_mixer_selem_register(mixer_, nullptr, nullptr)) < 0)
+    if (err = snd_mixer_selem_register(mixer_, nullptr, nullptr); err < 0)
         throw SnapException(std::string("Failed to register selem, error: ") + snd_strerror(err));
-    if ((err = snd_mixer_load(mixer_)) < 0)
+    if (err = snd_mixer_load(mixer_); err < 0)
         throw SnapException(std::string("Failed to load mixer, error: ") + snd_strerror(err));
     elem_ = snd_mixer_find_selem(mixer_, sid);
     if (elem_ == nullptr)
@@ -297,7 +298,7 @@ void AlsaPlayer::initAlsa()
     int err;
 
     // Open the PCM device in playback mode
-    if ((err = snd_pcm_open(&handle_, settings_.pcm_device.name.c_str(), SND_PCM_STREAM_PLAYBACK, 0)) < 0)
+    if (err = snd_pcm_open(&handle_, settings_.pcm_device.name.c_str(), SND_PCM_STREAM_PLAYBACK, 0); err < 0)
         throw SnapException("Can't open " + settings_.pcm_device.name + ", error: " + snd_strerror(err), err);
 
     // struct snd_pcm_playback_info_t pinfo;
@@ -308,7 +309,7 @@ void AlsaPlayer::initAlsa()
     // Allocate parameters object and fill it with default values
     snd_pcm_hw_params_t* params;
     snd_pcm_hw_params_alloca(&params);
-    if ((err = snd_pcm_hw_params_any(handle_, params)) < 0)
+    if (err = snd_pcm_hw_params_any(handle_, params); err < 0)
         throw SnapException("Can't fill params: " + string(snd_strerror(err)));
 
     snd_output_t* output;
@@ -324,7 +325,7 @@ void AlsaPlayer::initAlsa()
     }
 
     // Set parameters
-    if ((err = snd_pcm_hw_params_set_access(handle_, params, SND_PCM_ACCESS_RW_INTERLEAVED)) < 0)
+    if (err = snd_pcm_hw_params_set_access(handle_, params, SND_PCM_ACCESS_RW_INTERLEAVED); err < 0)
         throw SnapException("Can't set interleaved mode: " + string(snd_strerror(err)));
 
     snd_pcm_format_t snd_pcm_format;
@@ -367,17 +368,17 @@ void AlsaPlayer::initAlsa()
         throw SnapException(ss.str());
     }
 
-    if ((err = snd_pcm_hw_params_set_channels(handle_, params, channels)) < 0)
+    if (err = snd_pcm_hw_params_set_channels(handle_, params, channels); err < 0)
         throw SnapException("Can't set channel count: " + string(snd_strerror(err)));
 
-    if ((err = snd_pcm_hw_params_set_rate_near(handle_, params, &rate, nullptr)) < 0)
+    if (err = snd_pcm_hw_params_set_rate_near(handle_, params, &rate, nullptr); err < 0)
         throw SnapException("Can't set rate: " + string(snd_strerror(err)));
     if (rate != format.rate())
         LOG(WARNING, LOG_TAG) << "Could not set sample rate to " << format.rate() << " Hz, using: " << rate << " Hz\n";
 
     uint32_t period_time = buffer_time_.value_or(BUFFER_TIME).count() / periods_.value_or(PERIODS);
     uint32_t max_period_time = period_time;
-    if ((err = snd_pcm_hw_params_get_period_time_max(params, &max_period_time, nullptr)) < 0)
+    if (err = snd_pcm_hw_params_get_period_time_max(params, &max_period_time, nullptr); err < 0)
     {
         LOG(ERROR, LOG_TAG) << "Can't get max period time: " << snd_strerror(err) << "\n";
     }
@@ -390,7 +391,7 @@ void AlsaPlayer::initAlsa()
         }
     }
     uint32_t min_period_time = period_time;
-    if ((err = snd_pcm_hw_params_get_period_time_min(params, &min_period_time, nullptr)) < 0)
+    if (err = snd_pcm_hw_params_get_period_time_min(params, &min_period_time, nullptr); err < 0)
     {
         LOG(ERROR, LOG_TAG) << "Can't get min period time: " << snd_strerror(err) << "\n";
     }
@@ -403,7 +404,7 @@ void AlsaPlayer::initAlsa()
         }
     }
 
-    if ((err = snd_pcm_hw_params_set_period_time_near(handle_, params, &period_time, nullptr)) < 0)
+    if (err = snd_pcm_hw_params_set_period_time_near(handle_, params, &period_time, nullptr); err < 0)
         throw SnapException("Can't set period time: " + string(snd_strerror(err)));
 
     uint32_t buffer_time = buffer_time_.value_or(BUFFER_TIME).count();
@@ -415,15 +416,15 @@ void AlsaPlayer::initAlsa()
         buffer_time = period_time * periods;
     }
 
-    if ((err = snd_pcm_hw_params_set_buffer_time_near(handle_, params, &buffer_time, nullptr)) < 0)
+    if (err = snd_pcm_hw_params_set_buffer_time_near(handle_, params, &buffer_time, nullptr); err < 0)
         throw SnapException("Can't set buffer time to " + cpt::to_string(buffer_time) + " us : " + string(snd_strerror(err)));
 
     // unsigned int periods = periods_;
-    // if ((err = snd_pcm_hw_params_set_periods_near(handle_, params, &periods, 0)) < 0)
+    // if (err = snd_pcm_hw_params_set_periods_near(handle_, params, &periods, 0); err < 0)
     //     throw SnapException("Can't set periods: " + string(snd_strerror(err)));
 
     // Write parameters
-    if ((err = snd_pcm_hw_params(handle_, params)) < 0)
+    if (err = snd_pcm_hw_params(handle_, params); err < 0)
         throw SnapException("Can't set hardware parameters: " + string(snd_strerror(err)));
 
     // Resume information
@@ -447,7 +448,7 @@ void AlsaPlayer::initAlsa()
 
     if (snd_pcm_state(handle_) == SND_PCM_STATE_PREPARED)
     {
-        if ((err = snd_pcm_start(handle_)) < 0)
+        if (err = snd_pcm_start(handle_); err < 0)
             LOG(DEBUG, LOG_TAG) << "Failed to start PCM: " << snd_strerror(err) << "\n";
     }
 
@@ -518,7 +519,7 @@ void AlsaPlayer::start()
 
 AlsaPlayer::~AlsaPlayer()
 {
-    stop();
+    stop(); // NOLINT
 }
 
 
