@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2020  Johannes Pohl
+    Copyright (C) 2014-2025  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,27 +16,32 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 ***/
 
-#ifndef PCM_DEVICE_HPP
-#define PCM_DEVICE_HPP
+#pragma once
 
+// standard headers
 #include <string>
 
 namespace player
 {
 
+/// Name of the default audio device
 static constexpr char DEFAULT_DEVICE[] = "default";
 
+/// DAC identifier
 struct PcmDevice
 {
+    /// c'tor
     PcmDevice() : idx(-1), name(DEFAULT_DEVICE){};
 
-    PcmDevice(int idx, const std::string& name, const std::string& description = "") : idx(idx), name(name), description(description){};
+    /// c'tor
+    PcmDevice(int idx, std::string name, std::string description = "") : idx(idx), name(std::move(name)), description(std::move(description)){};
 
+    /// index of the DAC (as in "aplay -L")
     int idx;
+    /// device name
     std::string name;
+    /// device description
     std::string description;
 };
 
 } // namespace player
-
-#endif
