@@ -1,6 +1,6 @@
 /***
     This file is part of snapcast
-    Copyright (C) 2014-2024  Johannes Pohl
+    Copyright (C) 2014-2025  Johannes Pohl
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,10 +29,13 @@
 namespace encoder
 {
 
+/// Ogg encoder
 class OggEncoder : public Encoder
 {
 public:
-    OggEncoder(const std::string& codecOptions = "");
+    /// c'tor
+    explicit OggEncoder(std::string codecOptions);
+    /// d'tor
     ~OggEncoder() override;
 
     void encode(const msg::PcmChunk& chunk) override;
@@ -40,19 +43,18 @@ public:
     std::string getDefaultOptions() const override;
     std::string name() const override;
 
-protected:
+private:
     void initEncoder() override;
 
-private:
-    ogg_stream_state os_; /// take physical pages, weld into a logical stream of packets
-    ogg_page og_;         /// one Ogg bitstream page.  Vorbis packets are inside
-    ogg_packet op_;       /// one raw packet of data for decode
+    ogg_stream_state os_; ///< take physical pages, weld into a logical stream of packets
+    ogg_page og_;         ///< one Ogg bitstream page.  Vorbis packets are inside
+    ogg_packet op_;       ///< one raw packet of data for decode
 
-    vorbis_info vi_;    /// struct that stores all the static vorbis bitstream settings
-    vorbis_comment vc_; /// struct that stores all the user comments
+    vorbis_info vi_;    ///< struct that stores all the static vorbis bitstream settings
+    vorbis_comment vc_; ///< struct that stores all the user comments
 
-    vorbis_dsp_state vd_; /// central working state for the packet->PCM decoder
-    vorbis_block vb_;     /// local working space for packet->PCM decode
+    vorbis_dsp_state vd_; ///< central working state for the packet->PCM decoder
+    vorbis_block vb_;     ///< local working space for packet->PCM decode
 
     ogg_int64_t lastGranulepos_;
 };
