@@ -18,6 +18,8 @@
 
 // local headers
 #include "common/popl.hpp"
+#include <algorithm>
+#include <cstddef>
 #include <filesystem>
 #ifdef HAS_DAEMON
 #include "common/daemon.hpp"
@@ -28,14 +30,15 @@
 #include "encoder/encoder_factory.hpp"
 #include "server.hpp"
 #include "server_settings.hpp"
-#if defined(HAS_AVAHI) || defined(HAS_BONJOUR)
-#include "publishZeroConf/publish_mdns.hpp"
+#ifdef HAS_MDNS
+#include "publishZeroConf/publish_zeroconf.hpp"
 #endif
 #include "common/aixlog.hpp"
 #include "config.hpp"
 
 // 3rd party headers
 #include <boost/asio/ip/host_name.hpp>
+#include <boost/asio/signal_set.hpp>
 
 // standard headers
 #include <chrono>
@@ -70,7 +73,7 @@ int main(int argc, char* argv[])
         int processPriority(0);
         auto daemonOption = op.add<Implicit<int>>("d", "daemon", "Daemonize\noptional process priority [-20..19]", 0, &processPriority);
 #endif
-        op.add<Value<string>>("c", "config", "path to the configuration file", config_file, &config_file);
+        auto config_file_option = op.add<Value<string>>("c", "config", "Path to the configuration file", config_file, &config_file);
 
         OptionParser conf("Overridable config file options");
 
@@ -80,17 +83,21 @@ int main(int argc, char* argv[])
         conf.add<Value<string>>("", "server.user", "the user to run as when daemonized", settings.server.user, &settings.server.user);
         conf.add<Implicit<string>>("", "server.group", "the group to run as when daemonized", settings.server.group, &settings.server.group);
         conf.add<Implicit<string>>("", "server.datadir", "directory where persistent data is stored", settings.server.data_dir, &settings.server.data_dir);
+        conf.add<Value<bool>>("", "server.mdns_enabled", "enable mDNS to publish services", settings.server.mdns_enabled, &settings.server.mdns_enabled);
 
         // SSL settings
         conf.add<Value<std::filesystem::path>>("", "ssl.certificate", "certificate file (PEM format)", settings.ssl.certificate, &settings.ssl.certificate);
         conf.add<Value<std::filesystem::path>>("", "ssl.certificate_key", "private key file (PEM format)", settings.ssl.certificate_key,
                                                &settings.ssl.certificate_key);
         conf.add<Value<string>>("", "ssl.key_password", "key password (for encrypted private key)", settings.ssl.key_password, &settings.ssl.key_password);
+        conf.add<Value<bool>>("", "ssl.verify_clients", "Verify client certificates", settings.ssl.verify_clients, &settings.ssl.verify_clients);
+        auto client_cert_opt =
+            conf.add<Value<std::filesystem::path>>("", "ssl.client_cert", "List of client CA certificate files, can be configured multiple times", "");
 
-#if 0 // feature: users
-      // Users setting
-        auto users_value = conf.add<Value<string>>("", "users.user", "<User nane>:<permissions>:<password>");
-#endif
+        // Users setting
+        conf.add<Value<bool>>("", "authorization.enabled", "enabled authorization", settings.auth.enabled, &settings.auth.enabled);
+        auto roles_value = conf.add<Value<string>>("", "authorization.role", "<Role name>:<permissions>");
+        auto users_value = conf.add<Value<string>>("", "authorization.user", "<User nane>:<password>:<role>");
 
         // HTTP RPC settings
         conf.add<Value<bool>>("", "http.enabled", "enable HTTP Json RPC (HTTP POST and websockets)", settings.http.enabled, &settings.http.enabled);
@@ -105,18 +112,44 @@ int main(int argc, char* argv[])
         conf.add<Implicit<string>>("", "http.doc_root", "serve a website from the doc_root location", settings.http.doc_root, &settings.http.doc_root);
         conf.add<Value<string>>("", "http.host", "Hostname or IP under which clients can reach this host", settings.http.host, &settings.http.host);
         conf.add<Value<string>>("", "http.url_prefix", "URL prefix for generating album art URLs", settings.http.url_prefix, &settings.http.url_prefix);
+        conf.add<Value<bool>>("", "http.publish_http", "Publish HTTP service via mDNS", settings.http.publish_http, &settings.http.publish_http);
+        conf.add<Value<bool>>("", "http.publish_https", "Publish HTTPS service via mDNS", settings.http.publish_https, &settings.http.publish_https);
 
         // TCP RPC settings
-        conf.add<Value<bool>>("", "tcp.enabled", "enable TCP Json RPC)", settings.tcp.enabled, &settings.tcp.enabled);
-        conf.add<Value<size_t>>("", "tcp.port", "which port the server should listen on", settings.tcp.port, &settings.tcp.port);
-        auto tcp_bind_to_address = conf.add<Value<string>>("", "tcp.bind_to_address", "address for the server to listen on",
-                                                           settings.tcp.bind_to_address.front(), &settings.tcp.bind_to_address[0]);
+        // Deprecated: tcp.x => tcp-control.x
+        auto deprecated_tcp_enabled =
+            conf.add<Value<bool>>("", "tcp.enabled", "deprecated: use 'tcp-control.enabled'", settings.tcp_control.enabled, &settings.tcp_control.enabled);
+        auto deprecated_tcp_port =
+            conf.add<Value<size_t>>("", "tcp.port", "deprecated: use 'tcp-control.port'", settings.tcp_control.port, &settings.tcp_control.port);
+        auto deprecated_tcp_bind_to_address = conf.add<Value<string>>("", "tcp.bind_to_address", "deprecated: use 'tcp-control.bind_to_address'",
+                                                                      settings.tcp_control.bind_to_address.front(), &settings.tcp_control.bind_to_address[0]);
+
+        // Deprecated: stream.x => tcp-streaming.x
+        auto deprecated_stream_bind_to_address = conf.add<Value<string>>("", "stream.bind_to_address", "deprecated: use 'tcp-streaming.bind_to_address'",
+                                                                         settings.tcp_stream.bind_to_address.front(), &settings.tcp_stream.bind_to_address[0]);
+        auto deprecated_stream_port =
+            conf.add<Value<size_t>>("", "stream.port", "deprecated: use 'tcp-streaming.port'", settings.tcp_stream.port, &settings.tcp_stream.port);
+
+
+        conf.add<Value<bool>>("", "tcp-control.enabled", "enable TCP Json RPC)", settings.tcp_control.enabled, &settings.tcp_control.enabled);
+        conf.add<Value<size_t>>("", "tcp-control.port", "which control port the server should listen on", settings.tcp_control.port,
+                                &settings.tcp_control.port);
+        auto control_bind_to_address = conf.add<Value<string>>("", "tcp-control.bind_to_address", "address for the control server to listen on",
+                                                               settings.tcp_control.bind_to_address.front(), &settings.tcp_control.bind_to_address[0]);
+        conf.add<Value<bool>>("", "tcp-control.publish", "Publish TCP control service via mDNS", settings.tcp_control.publish, &settings.tcp_control.publish);
+
+        // TCP Streaming settings
+        conf.add<Value<bool>>("", "tcp-streaming.enabled", "enable TCP streaming)", settings.tcp_stream.enabled, &settings.tcp_stream.enabled);
+        conf.add<Value<size_t>>("", "tcp-streaming.port", "which streaming port the server should listen on", settings.tcp_stream.port,
+                                &settings.tcp_stream.port);
+        auto stream_bind_to_address = conf.add<Value<string>>("", "tcp-streaming.bind_to_address", "address for the streaming server to listen on",
+                                                              settings.tcp_stream.bind_to_address.front(), &settings.tcp_stream.bind_to_address[0]);
+        conf.add<Value<bool>>("", "tcp-streaming.publish", "Publish TCP streaming service via mDNS", settings.tcp_stream.publish, &settings.tcp_stream.publish);
 
         // stream settings
         conf.add<Value<std::filesystem::path>>("", "stream.plugin_dir", "stream plugin directory", settings.stream.plugin_dir, &settings.stream.plugin_dir);
-        auto stream_bind_to_address = conf.add<Value<string>>("", "stream.bind_to_address", "address for the server to listen on",
-                                                              settings.stream.bind_to_address.front(), &settings.stream.bind_to_address[0]);
-        conf.add<Value<size_t>>("", "stream.port", "which port the server should listen on", settings.stream.port, &settings.stream.port);
+        conf.add<Value<std::filesystem::path>>("", "stream.sandbox_dir", "directory with executable process stream sources", settings.stream.sandbox_dir,
+                                               &settings.stream.sandbox_dir);
         // deprecated: stream.stream, use stream.source instead
         auto streamValue = conf.add<Value<string>>("", "stream.stream", "Deprecated: use stream.source", pcmSource, &pcmSource);
         auto sourceValue = conf.add<Value<string>>(
@@ -145,35 +178,10 @@ int main(int argc, char* argv[])
             "log filter <tag>:<level>[,<tag>:<level>]* with tag = * or <log tag> and level = [trace,debug,info,notice,warning,error,fatal]",
             settings.logging.filter);
 
+        // Parse command line arguments
         try
         {
             op.parse(argc, argv);
-            conf.parse(config_file);
-            conf.parse(argc, argv);
-            if (tcp_bind_to_address->is_set())
-            {
-                settings.tcp.bind_to_address.clear();
-                for (size_t n = 0; n < tcp_bind_to_address->count(); ++n)
-                    settings.tcp.bind_to_address.push_back(tcp_bind_to_address->value(n));
-            }
-            if (http_bind_to_address->is_set())
-            {
-                settings.http.bind_to_address.clear();
-                for (size_t n = 0; n < http_bind_to_address->count(); ++n)
-                    settings.http.bind_to_address.push_back(http_bind_to_address->value(n));
-            }
-            if (http_ssl_bind_to_address->is_set())
-            {
-                settings.http.ssl_bind_to_address.clear();
-                for (size_t n = 0; n < http_ssl_bind_to_address->count(); ++n)
-                    settings.http.ssl_bind_to_address.push_back(http_ssl_bind_to_address->value(n));
-            }
-            if (stream_bind_to_address->is_set())
-            {
-                settings.stream.bind_to_address.clear();
-                for (size_t n = 0; n < stream_bind_to_address->count(); ++n)
-                    settings.stream.bind_to_address.push_back(stream_bind_to_address->value(n));
-            }
         }
         catch (const std::invalid_argument& e)
         {
@@ -208,6 +216,24 @@ int main(int argc, char* argv[])
             exit(EXIT_SUCCESS);
         }
 
+        // Parse configuration file and overrides from command line
+        try
+        {
+            conf.parse(config_file);
+            conf.parse(argc, argv);
+        }
+        catch (const std::invalid_argument& e)
+        {
+            if (config_file_option->is_set())
+            {
+                cerr << "Exception: " << e.what() << "\n";
+                cout << "\n" << op << "\n";
+                exit(EXIT_FAILURE);
+            }
+            else
+                cerr << "Warning - Failed to load config file '" << config_file << "': " << e.what() << "\n";
+        }
+
         if (settings.stream.codec.find(":?") != string::npos)
         {
             encoder::EncoderFactory encoderFactory;
@@ -258,6 +284,57 @@ int main(int argc, char* argv[])
         else
             throw SnapException("Invalid log sink: " + settings.logging.sink);
 
+#ifndef HAS_OPENSSL
+        if (settings.http.ssl_enabled)
+            throw SnapException("HTTPS enabled ([http] ssl_enabled), but snapserrver is built without ssl support");
+#endif
+
+        if (deprecated_tcp_enabled->is_set())
+            LOG(WARNING, LOG_TAG) << "Option '" << deprecated_tcp_enabled->long_name() << "' is " << deprecated_tcp_enabled->description() << "\n";
+        if (deprecated_tcp_port->is_set())
+            LOG(WARNING, LOG_TAG) << "Option '" << deprecated_tcp_port->long_name() << "' is " << deprecated_tcp_port->description() << "\n";
+        if (deprecated_tcp_bind_to_address->is_set())
+        {
+            LOG(WARNING, LOG_TAG) << "Option '" << deprecated_tcp_bind_to_address->long_name() << "' is " << deprecated_tcp_bind_to_address->description()
+                                  << "\n";
+            if (!control_bind_to_address->is_set())
+                control_bind_to_address = deprecated_tcp_bind_to_address;
+        }
+        if (deprecated_stream_bind_to_address->is_set())
+        {
+            LOG(WARNING, LOG_TAG) << "Option '" << deprecated_stream_bind_to_address->long_name() << "' is " << deprecated_stream_bind_to_address->description()
+                                  << "\n";
+            if (!stream_bind_to_address->is_set())
+                stream_bind_to_address = deprecated_stream_bind_to_address;
+        }
+        if (deprecated_stream_port->is_set())
+            LOG(WARNING, LOG_TAG) << "Option '" << deprecated_stream_port->long_name() << "' is " << deprecated_stream_port->description() << "\n";
+
+        if (control_bind_to_address->is_set())
+        {
+            settings.tcp_control.bind_to_address.clear();
+            for (size_t n = 0; n < control_bind_to_address->count(); ++n)
+                settings.tcp_control.bind_to_address.push_back(control_bind_to_address->value(n));
+        }
+        if (http_bind_to_address->is_set())
+        {
+            settings.http.bind_to_address.clear();
+            for (size_t n = 0; n < http_bind_to_address->count(); ++n)
+                settings.http.bind_to_address.push_back(http_bind_to_address->value(n));
+        }
+        if (http_ssl_bind_to_address->is_set())
+        {
+            settings.http.ssl_bind_to_address.clear();
+            for (size_t n = 0; n < http_ssl_bind_to_address->count(); ++n)
+                settings.http.ssl_bind_to_address.push_back(http_ssl_bind_to_address->value(n));
+        }
+        if (stream_bind_to_address->is_set())
+        {
+            settings.tcp_stream.bind_to_address.clear();
+            for (size_t n = 0; n < stream_bind_to_address->count(); ++n)
+                settings.tcp_stream.bind_to_address.push_back(stream_bind_to_address->value(n));
+        }
+
         if (!settings.ssl.certificate.empty() && !settings.ssl.certificate_key.empty())
         {
             namespace fs = std::filesystem;
@@ -276,6 +353,13 @@ int main(int argc, char* argv[])
             settings.ssl.certificate_key = make_absolute(settings.ssl.certificate_key);
             if (!fs::exists(settings.ssl.certificate_key))
                 throw SnapException("SSL certificate_key file not found: " + settings.ssl.certificate_key.native());
+            for (size_t n = 0; n < client_cert_opt->count(); ++n)
+            {
+                auto cert_file = std::filesystem::weakly_canonical(client_cert_opt->value(n));
+                if (!fs::exists(cert_file))
+                    throw SnapException("Client certificate file not found: " + cert_file.string());
+                settings.ssl.client_certs.push_back(std::move(cert_file));
+            }
         }
         else if (settings.ssl.certificate.empty() != settings.ssl.certificate_key.empty())
         {
@@ -298,7 +382,8 @@ int main(int argc, char* argv[])
             settings.stream.sources.push_back(sourceValue->value());
 
         settings.stream.plugin_dir = std::filesystem::weakly_canonical(settings.stream.plugin_dir);
-        LOG(INFO, LOG_TAG) << "Stream plugin directory: " << settings.stream.plugin_dir << "\n";
+        settings.stream.sandbox_dir = std::filesystem::weakly_canonical(settings.stream.sandbox_dir);
+        LOG(INFO, LOG_TAG) << "Stream plugin directory: '" << settings.stream.plugin_dir << "', sandbox directory: '" << settings.stream.sandbox_dir << "'\n";
         for (size_t n = 0; n < streamValue->count(); ++n)
         {
             LOG(INFO, LOG_TAG) << "Adding stream: " << streamValue->value(n) << "\n";
@@ -310,15 +395,26 @@ int main(int argc, char* argv[])
             settings.stream.sources.push_back(sourceValue->value(n));
         }
 
-#if 0 // feature: users
-        for (size_t n = 0; n < users_value->count(); ++n)
+        // TODO: auth
+        settings.auth.enabled = false;
+        if (settings.auth.enabled)
         {
-            settings.users.emplace_back(users_value->value(n));
-            LOG(DEBUG, LOG_TAG) << "User: " << settings.users.back().name
-                                << ", permissions: " << utils::string::container_to_string(settings.users.back().permissions)
-                                << ", pw: " << settings.users.back().password << "\n";
+            std::vector<std::string> roles;
+            roles.reserve(roles_value->count());
+            for (size_t n = 0; n < roles_value->count(); ++n)
+                roles.push_back(roles_value->value(n));
+            std::vector<std::string> users;
+            users.reserve(users_value->count());
+            for (size_t n = 0; n < users_value->count(); ++n)
+                users.push_back(users_value->value(n));
+
+            settings.auth.init(roles, users);
+
+            for (const auto& role : settings.auth.roles)
+                LOG(DEBUG, LOG_TAG) << "Role: " << role->role << ", permissions: " << utils::string::container_to_string(role->permissions) << "\n";
+            for (const auto& user : settings.auth.users)
+                LOG(DEBUG, LOG_TAG) << "User: " << user.name << ", pw: " << user.password << ", role: " << user.role_name << "\n";
         }
-#endif
 
 #ifdef HAS_DAEMON
         std::unique_ptr<Daemon> daemon;
@@ -346,26 +442,32 @@ int main(int argc, char* argv[])
 #endif
 
         boost::asio::io_context io_context;
-#if defined(HAS_AVAHI) || defined(HAS_BONJOUR)
-        auto publishZeroConfg = std::make_unique<PublishZeroConf>("Snapcast", io_context);
-        vector<mDNSService> dns_services;
-        dns_services.emplace_back("_snapcast._tcp", settings.stream.port);
-        dns_services.emplace_back("_snapcast-stream._tcp", settings.stream.port);
-        if (settings.tcp.enabled)
+#ifdef HAS_MDNS
+        std::unique_ptr<PublishZeroConf> publishZeroConfg;
+        if (settings.server.mdns_enabled)
         {
-            dns_services.emplace_back("_snapcast-jsonrpc._tcp", settings.tcp.port);
-            dns_services.emplace_back("_snapcast-tcp._tcp", settings.tcp.port);
-        }
-        if (settings.http.enabled)
-        {
-            dns_services.emplace_back("_snapcast-http._tcp", settings.http.port);
-        }
-        if (settings.http.ssl_enabled)
-        {
-            dns_services.emplace_back("_snapcast-https._tcp", settings.http.ssl_port);
-        }
+            publishZeroConfg = std::make_unique<PublishZeroConf>("Snapcast", io_context);
+            vector<mDNSService> dns_services;
+            if (settings.tcp_stream.enabled && settings.tcp_stream.publish)
+            {
+                dns_services.emplace_back("_snapcast._tcp", settings.tcp_stream.port);
+                // dns_services.emplace_back("_snapcast-stream._tcp", settings.tcp_stream.port);
+            }
+            if (settings.tcp_control.enabled && settings.tcp_control.publish)
+            {
+                dns_services.emplace_back("_snapcast-ctrl._tcp", settings.tcp_control.port);
+            }
+            if (settings.http.enabled && settings.http.publish_http)
+            {
+                dns_services.emplace_back("_snapcast-http._tcp", settings.http.port);
+            }
+            if (settings.http.ssl_enabled && settings.http.publish_https)
+            {
+                dns_services.emplace_back("_snapcast-https._tcp", settings.http.ssl_port);
+            }
 
-        publishZeroConfg->publish(dns_services);
+            publishZeroConfg->publish(dns_services);
+        }
 #endif
         if (settings.http.enabled || settings.http.ssl_enabled)
         {
