@@ -23,6 +23,8 @@
 #include "common/aixlog.hpp"
 
 // 3rd party headers
+#include <boost/asio/read.hpp>
+#include <boost/asio/write.hpp>
 
 // standard headers
 #include <iostream>
@@ -34,8 +36,8 @@ using namespace streamreader;
 static constexpr auto LOG_TAG = "StreamSessionTCP";
 
 
-StreamSessionTcp::StreamSessionTcp(StreamMessageReceiver* receiver, tcp::socket&& socket)
-    : StreamSession(socket.get_executor(), receiver), socket_(std::move(socket))
+StreamSessionTcp::StreamSessionTcp(StreamMessageReceiver* receiver, const ServerSettings& server_settings, tcp::socket&& socket)
+    : StreamSession(socket.get_executor(), server_settings, receiver), socket_(std::move(socket))
 {
 }
 
@@ -43,13 +45,13 @@ StreamSessionTcp::StreamSessionTcp(StreamMessageReceiver* receiver, tcp::socket&
 StreamSessionTcp::~StreamSessionTcp()
 {
     LOG(DEBUG, LOG_TAG) << "~StreamSessionTcp\n";
-    stop();
+    stop(); // NOLINT
 }
 
 
 void StreamSessionTcp::start()
 {
-    read_next();
+    readNext();
 }
 
 
@@ -83,7 +85,7 @@ std::string StreamSessionTcp::getIP()
 }
 
 
-void StreamSessionTcp::read_next()
+void StreamSessionTcp::readNext()
 {
     boost::asio::async_read(socket_, boost::asio::buffer(buffer_, base_msg_size_),
                             [this, self = shared_from_this()](boost::system::error_code ec, std::size_t length) mutable
@@ -126,15 +128,19 @@ void StreamSessionTcp::read_next()
             tv now;
             baseMessage_.received = now;
             if (messageReceiver_ != nullptr)
-                messageReceiver_->onMessageReceived(this, baseMessage_, buffer_.data());
-            read_next();
+                messageReceiver_->onMessageReceived(shared_from_this(), baseMessage_, buffer_.data());
+            readNext();
         });
     });
 }
 
 
-void StreamSessionTcp::sendAsync(const shared_const_buffer& buffer, const WriteHandler& handler)
+void StreamSessionTcp::sendAsync(const shared_const_buffer& buffer, WriteHandler&& handler)
 {
     boost::asio::async_write(socket_, buffer,
-                             [self = shared_from_this(), buffer, handler](boost::system::error_code ec, std::size_t length) { handler(ec, length); });
+                             [self = shared_from_this(), buffer, handler = std::move(handler)](boost::system::error_code ec, std::size_t length)
+    {
+        if (handler)
+            handler(ec, length);
+    });
 }
